summaryrefslogtreecommitdiff
path: root/tools/sample_data.sh
diff options
context:
space:
mode:
authorTom Fifield <tom@openstack.org>2013-10-19 11:02:17 +1100
committerBrant Knudson <bknudson@us.ibm.com>2013-11-10 18:04:07 -0600
commit994be740d4709539f0f598e22658aa1785f4c6d2 (patch)
tree442e83b1166de788948a331323cb7c4625046b18 /tools/sample_data.sh
parenta0e26c1882d83989bee3726a5ae08cbe3f32a2b5 (diff)
downloadkeystone-994be740d4709539f0f598e22658aa1785f4c6d2.tar.gz
Change deprecated CLI arguments
According to keystoneclient/shell.py, --token and --endpoint (with their accompanying ENV vars SERVICE_TOKEN and SERVICE_ENDPOINT) were retained only for Essex compatibility and should have been removed during Grizzly, replaced with --os-token (OS_SERVICE_TOKEN) and --os-endpoint (OS_SERVICE_ENDPOINT). This patch updates a couple of doc references to the old options, and the sample_data tool. Change-Id: I87060764f40b1612e3a440c3406d094536af4c9c
Diffstat (limited to 'tools/sample_data.sh')
-rwxr-xr-xtools/sample_data.sh12
1 files changed, 6 insertions, 6 deletions
diff --git a/tools/sample_data.sh b/tools/sample_data.sh
index d09502d68..a9bf50483 100755
--- a/tools/sample_data.sh
+++ b/tools/sample_data.sh
@@ -19,8 +19,8 @@
# This script is based on the original DevStack keystone_data.sh script.
#
# It demonstrates how to bootstrap Keystone with an administrative user
# using the SERVICE_TOKEN and SERVICE_ENDPOINT environment variables
# and the administrative API. It will get the admin_token (SERVICE_TOKEN)
# and admin_port from keystone.conf if available.
#
# Disable creation of endpoints by setting DISABLE_ENDPOINTS environment variable.
@@ -71,14 +71,14 @@ if [[ -r "$KEYSTONE_CONF" ]]; then
CONFIG_ADMIN_PORT=$(sed 's/[[:space:]]//g' $KEYSTONE_CONF | grep ^admin_port= | cut -d'=' -f2)
fi
-export SERVICE_TOKEN=${SERVICE_TOKEN:-$CONFIG_SERVICE_TOKEN}
-if [[ -z "$SERVICE_TOKEN" ]]; then
+export OS_SERVICE_TOKEN=${OS_SERVICE_TOKEN:-$CONFIG_SERVICE_TOKEN}
+if [[ -z "$OS_SERVICE_TOKEN" ]]; then
echo "No service token found."
- echo "Set SERVICE_TOKEN manually from keystone.conf admin_token."
+ echo "Set OS_SERVICE_TOKEN manually from keystone.conf admin_token."
exit 1
fi
-export SERVICE_ENDPOINT=${SERVICE_ENDPOINT:-http://$CONTROLLER_PUBLIC_ADDRESS:${CONFIG_ADMIN_PORT:-35357}/v2.0}
+export OS_SERVICE_ENDPOINT=${OS_SERVICE_ENDPOINT:-http://$CONTROLLER_PUBLIC_ADDRESS:${CONFIG_ADMIN_PORT:-35357}/v2.0}
function get_id () {
echo `"$@" | grep ' id ' | awk '{print $4}'`
@@ -19,8 +19,8 @@
#
# It demonstrates how to bootstrap Keystone with an administrative user
-# using the SERVICE_TOKEN and SERVICE_ENDPOINT environment variables
-# and the administrative API. It will get the admin_token (SERVICE_TOKEN)
+# using the OS_SERVICE_TOKEN and OS_SERVICE_ENDPOINT environment variables
+# and the administrative API. It will get the admin_token (OS_SERVICE_TOKEN)
# and admin_port from keystone.conf if available.
#